Struct google_chat1::api::Space [−][src]
A room or DM in Hangouts Chat.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- members get spaces (none)
- members list spaces (none)
- messages attachments get spaces (none)
- messages create spaces (none)
- messages delete spaces (none)
- messages get spaces (none)
- messages update spaces (none)
- get spaces (response)
- list spaces (none)
- webhooks spaces (none)
Fields
display_name: Option<String>Output only. The display name (only if the space is a room). Please note that this field might not be populated in direct messages between humans.
name: Option<String>Resource name of the space, in the form “spaces/*”. Example: spaces/AAAAMpdlehYs
single_user_bot_dm: Option<bool>Whether the space is a DM between a bot and a single human.
threaded: Option<bool>Whether the messages are threaded in this space.
type_: Option<String>Output only. The type of a space. This is deprecated. Use single_user_bot_dm instead.